@@ -1,15 +1,15 @@
-import Planner from './components/planner';
 import Catalog from './catalog/catalog';
 import Translator from './translator/translator';
 import ToolbarButton from './components/toolbar/toolbar-button';
 import Ruler from './components/viewer2d/ruler';
 import * as Models from './models'
-import PluginBrowserAutosave from './plugins/browser-autosave/browser-autosave';
 import State2DViewer from './components/viewer2d/state';
-import AppReducer from './reducers/reducer';
+import reducer from './reducers/reducer';
+import ReactPlanner from './react-planner';
+import Plugins from './plugins/plugins';
 
 console.info(`react-planner started`); //MIT LICENSE COMPLIANT
 
 export {
-  Planner, Catalog, Translator, ToolbarButton, Ruler, Models, PluginBrowserAutosave, State2DViewer, AppReducer
+  Catalog, Translator, ToolbarButton, Ruler, Models, State2DViewer, reducer, ReactPlanner, Plugins
 };
